@@ -254,7 +254,7 @@ class Results(object):
             'sig': '$\\sigma$ [m/s]',
             'mtot': '$M_T$ [M$_\\odot$]',
             'm0': '$M_0$ [M$_\\odot$]',
-            'm': '$M_{0}$ [M$_\{Jup\}$]',
+            'm': '$M_{0}$ [M$_\{{Jup\}}$]',
         }
 
         if param_list is None:
@@ -418,7 +418,7 @@ class Results(object):
                 # Calculate ra/dec offsets for all epochs of this orbit
                 raoff0, deoff0, _ = kepler.calc_orbit(
                     epochs[i, :], sma[orb_ind], ecc[orb_ind], inc[orb_ind], aop[orb_ind], pan[orb_ind],
-                    tau[orb_ind], plx[orb_ind], mtot[orb_ind], tau_ref_epoch=self.tau_ref_epoch,
+                    tau[orb_ind], plx[orb_ind], mtot[orb_ind], tau_ref_epoch=self.tau_ref_epoch, tau_warning=False
                 )
 
                 raoff[i, :] = raoff0
@@ -515,7 +515,7 @@ class Results(object):
                     raoff0, deoff0, vzoff0 = kepler.calc_orbit(
                         epochs_seppa[i, :], sma[orb_ind], ecc[orb_ind], inc[orb_ind], aop[orb_ind], pan[orb_ind],
                         tau[orb_ind], plx[orb_ind], mtot[orb_ind], tau_ref_epoch=self.tau_ref_epoch,
-                        mass_for_Kamp=m0[orb_ind]
+                        mass_for_Kamp=m0[orb_ind], tau_warning=False
                     )
 
                     raoff[i, :] = raoff0
@@ -525,15 +525,13 @@ class Results(object):
                 else:
                     raoff0, deoff0, _ = kepler.calc_orbit(
                         epochs_seppa[i, :], sma[orb_ind], ecc[orb_ind], inc[orb_ind], aop[orb_ind], pan[orb_ind],
-                        tau[orb_ind], plx[orb_ind], mtot[orb_ind], tau_ref_epoch=self.tau_ref_epoch,
+                        tau[orb_ind], plx[orb_ind], mtot[orb_ind], tau_ref_epoch=self.tau_ref_epoch, tau_warning=False
                     )
 
                     raoff[i, :] = raoff0
                     deoff[i, :] = deoff0
 
                 yr_epochs = Time(epochs_seppa[i, :], format='mjd').decimalyear
-                plot_epochs = np.where(yr_epochs <= sep_pa_end_year)[0]
-                yr_epochs = yr_epochs[plot_epochs]
 
                 seps, pas = orbitize.system.radec2seppa(raoff[i, :], deoff[i, :], mod180=mod180)
 
